<?php

namespace Drupal\entity_manager\Plugin\EntityManager;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Routing\RouteMatch;
use Drupal\entity_manager\Entity\EntityManagerItem;
use Drupal\entity_manager\EntityManagerPluginBase;

/**
 * Plugin implementation of the entity_manager.
 *
 * @EntityManager(
 *   id = "translate",
 *   label = @Translation("Translate"),
 *   weight = 10,
 *   description = @Translation("Entity translations.")
 * )
 */
class Translate extends EntityManagerPluginBase
{

    /**
     *
     */
    public function buildPage(EntityManagerItem $entity_manager_item, ?EntityInterface $entity = null)
    {
        $build = [
        '#markup' => t('No translations for %title', ['%title' => $entity->label()]),
        ];
        if ($entity->getEntityType()->hasLinkTemplate('drupal:content-translation-overview')) {
            // Get route from route name.
            $entity_type_id = $entity->getEntityTypeId();
            $route_name = "entity.$entity_type_id.content_translation_overview";
            $route = \Drupal::service('router.route_provider')->getRouteByName($route_name);
            $parent_controller_id = $route->getDefault('_controller');

            // Let the original controller build the form it wants to.
            if ($parent_controller = \Drupal::service('controller_resolver')->getControllerFromDefinition($parent_controller_id)) {
                $route_match = \Drupal::routeMatch();
                if($entity_manager_item = $route_match->getParameter('entity_manager_item')) {
                    $parameters = $route_match->getParameters()->all();
                    $parameters[$entity_type_id] = $parameters['entity'];
                    $parameters_raw = $route_match->getRawParameters()->all();
                    $parameters_raw[$entity_type_id] = $parameters_raw['entity'];

                    $new_route_match = new RouteMatch(
                        $route_match->getRouteName(),
                        $route_match->getRouteObject(),
                        $parameters,
                        $parameters_raw
                    );
                }
                $build = call_user_func([$parent_controller[0], $parent_controller[1]], $new_route_match, $entity_type_id);
            }
        }
        return $build;
    }

}
